View source: R/groupRAR_functions.R
| WeiUrn | R Documentation |
Simulating Wei's urn, the randomized play-the-winner rule for multiple arms (number of arms \ge 2), with two-sided hypothesis testing in a clinical trial context.
WeiUrn(k, p, ssn, Y0 = NULL, nsim = 2000, alpha = 0.05, test.fun = NULL,
typeI = FALSE, seed = NULL)
k |
A positive integer. The number of treatment groups in the trial ( |
p |
A vector of length |
ssn |
A positive integer. The total number of participants in each simulated trial. |
Y0 |
A vector of length |
nsim |
A positive integer. The number of simulated trials, with a default value of 2000. |
alpha |
A number between 0 and 1. The significance level of the two-sided test, with a default value of 0.05. |
test.fun |
An optional function |
typeI |
Logical. If |
seed |
An optional integer passed to |
Wei's urn procedure extends the randomized play-the-winner rule (Wei and Durham, 1978) from k = 2 to k > 2 treatments, which makes it usable in multi-arm clinical trials. A success on treatment k adds one ball of type k to the urn, and a failure on treatment k adds 1/(K-1) balls of each of the other K-1 types. With k = 2 it reduces to the randomized play-the-winner rule.
An object of class "grouprar", a list that is printed as a short summary (see print.grouprar), with the following elements.
method |
The name of the procedure. |
sample size |
The total sample size. |
parameter |
The true success rates used in the simulations, named |
propotion |
The mean allocation proportion of each arm over the simulations, named |
sd of propotion |
The standard deviation of the allocation proportion of each arm over the simulations. |
failure rate |
The mean failure rate over the simulations. |
sd of failure rate |
The standard deviation of the failure rate (or mean response) over the simulations. |
power |
The proportion of simulated trials that reject the null hypothesis of equal success rates. Simulations in which the test cannot be computed are dropped. |
data: failureRate |
The failure rate (or mean response) of each simulated trial. |
data: test |
The test decision of each simulated trial (1 = reject). |
data: assignment |
The treatment assignments of the last simulated trial. |
data: propotion |
A data frame with the allocation proportions of each simulated trial. |
data: allocation |
An |
type I error |
Only if |
Wei, L. J. (1979). The generalized Polya's urn design for sequential medical trials. The Annals of Statistics, 7(2), 291-296. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/aos/1176344614")}
Wei, L. J. and Durham, S. (1978). The randomized play-the-winner rule in medical trials. Journal of the American Statistical Association, 73(364), 840-843.
## a simple use
wei.res <- WeiUrn(k = 3, p = c(0.7, 0.8, 0.7), ssn = 200, Y0 = NULL, nsim = 100, alpha = 0.05)
## view the output
wei.res
## view all simulation settings
wei.res[["method"]]
wei.res[["parameter"]]
## view the simulation results
wei.res[["propotion"]]
wei.res[["failure rate"]]
wei.res[["power"]]
wei.res[["data: assignment"]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.